# ISOSIMpy

A GUI for groundwater age simulations using lumped parameter models.

```{toctree}
:maxdepth: 2
:caption: Guides
:hidden:

usage
dev
```

```{toctree}
:maxdepth: 2
:caption: API Reference

api/modules
```
